@@ -516,118 +516,3 @@ def plot_frequency_histogram_2D(fig_size:Tuple[int, int],
 
     return figure, ax
 
-def plot_convergence(gp_regressor, x_range, y_range, x_data_points, y_data_points, figure_size=(12, 4), function_colors=["lightgreen", "lightblue", "mediumpurple", "black"]):
-    """
-        Visualize Gaussian Process (GP) regression convergence.
-
-        This function fits a GaussianProcessRegressor incrementally as more data points are added,
-        plots the GP mean function at selected quantiles of the training process, and shows
-        the convergence of the mean squared error (MSE) between each trial and the final trial.
-
-        Arguments:
-            gp_regressor (GaussianProcessRegressor): 
-                An initialized scikit-learn GaussianProcessRegressor object.
-                Raises TypeError if the object is not of this type.
-            x_range (array-like): 
-                Full range of possible X values.
-            y_range (array-like): 
-                Full range of possible Y values.
-            x_data_points (array-like): 
-                Observed X data points.
-            y_data_points (array-like): 
-                Observed Y data points.
-            figure_size (tuple, optional): 
-                Size of the figure as (width, height). Defaults to (12, 4).
-            function_colors (list of strings, optional): 
-                Colors for visualizing GP mean functions at different quantiles. 
-                Defaults to ["lightgreen", "lightblue", "mediumpurple", "black"].
-
-        Returns:
-            tuple:
-                - figure (matplotlib.figure.Figure): The overall figure object.
-                - axes (numpy.ndarray of matplotlib.axes.Axes): Array containing the two subplot axes.
-
-        Raises:
-            TypeError: If `gp_regressor` is not an instance of 
-                    sklearn.gaussian_process.GaussianProcessRegressor.
-            ValueError: If the lengths of `x_data_points` and `y_data_points` do not match
-    """
-
-    if not isinstance(gp_regressor, GaussianProcessRegressor):
-        raise TypeError(
-            f"gp_regressor must be sklearn.gaussian_process.GaussianProcessRegressor, "
-            f"got {type(gp_regressor).__name__}."
-        )
-    
-    if len(x_data_points) != len(y_data_points):
-        raise ValueError(
-            f"x_data_points and y_data_points must have the same length, "
-            f"got {len(x_data_points)} and {len(y_data_points)} for x and y respectively."
-        )
-
-    num_data_points = len(x_data_points)
-        
-    figure, axes = plt.subplots(1, 2, figsize=figure_size)
-    gp_mean_function_list = []
-
-    quantiles_visualize = [0.25, 0.5, 0.75, 1]
-    n_trials_visualize = []
-    for quantile in quantiles_visualize:
-        n_trials_visualize.append(int(num_data_points * quantile))
-
-    # Generate plot 1: GP mean functions visualized
-    x_range_reshaped_for_gpr = np.array(x_range).reshape(-1, 1)
-    quantile_count = 0
-    for i in range(1, num_data_points+1):
-        x_data_points_current_trial = x_data_points[:i]
-        x_data_points_reshaped_for_gpr = np.array(x_data_points_current_trial).reshape(-1, 1)
-
-        y_data_points_current_trial = y_data_points[:i]
-        y_data_points_reshaped_for_gpr = np.array(y_data_points_current_trial).reshape(-1, 1)
-        
-        gp_regressor.fit(x_data_points_reshaped_for_gpr, y_data_points_reshaped_for_gpr)
-
-        gp_mean_function = gp_regressor.predict(x_range_reshaped_for_gpr)
-
-        gp_mean_function_list.append(gp_mean_function)
-        
-        if i in n_trials_visualize[:-1]:
-            current_quantile = int(quantiles_visualize[quantile_count] * 100)
-            axes[0].plot(x_range, gp_mean_function, color=function_colors[quantile_count], linewidth=2, label=f"Trial #{i} ({current_quantile}%)")
-            quantile_count += 1
-        elif i == n_trials_visualize[-1]:
-            axes[0].plot(x_range, gp_mean_function, color=function_colors[-1], linewidth=2.5, label="Final Trial")
-
-
-    # Set plot margins for better visibility
-    ymin, ymax = min(y_range), max(y_range)
-    span = ymax - ymin
-    margin = 0.1 * span
-    axes[0].set_ylim(ymin - margin, ymax + margin)
-    axes[0].set_title("GP mean functions visualized")
-    axes[0].legend()
-
-    # Data points scatter
-    axes[0].scatter(x_data_points, y_data_points, c="darkgrey", edgecolor="white", zorder=3, s=30)
-
-    # Generate plot 2: MSE value between each trial and the final trial
-    mse_values = []
-    print(num_data_points)
-    print(len(gp_mean_function_list))
-    for i in range(num_data_points):
-        mse = mean_squared_error(gp_mean_function_list[i], gp_mean_function_list[-1])
-        mse_values.append(mse)
-
-    trials = np.arange(1, len(mse_values) + 1) 
-    axes[1].plot(trials, mse_values, marker='o', linewidth=2)
-    axes[1].xaxis.set_major_locator(MultipleLocator(1))
-    axes[1].set_xlim(0.5, len(mse_values)+0.5)
-    axes[1].set_xlabel("Trial")
-    axes[1].set_ylabel("MSE")
-    axes[1].set_title("Distance to the final function")
-    axes[1].grid(True, alpha=0.3)
-
-    figure.tight_layout()
-    figure.suptitle("Convergence Plot", fontsize=16, y=1.03)
-
-    return figure, axes
\ No newline at end of file
